var annotated_dup =
[
    [ "la_xisnan", "d7/d91/namespacela__xisnan.html", [
      [ "la_isnan", "d8/dee/interfacela__xisnan_1_1la__isnan.html", "d8/dee/interfacela__xisnan_1_1la__isnan" ]
    ] ],
    [ "CBLAS_TEST_COMPLEX", "dd/d9b/struct_c_b_l_a_s___t_e_s_t___c_o_m_p_l_e_x.html", "dd/d9b/struct_c_b_l_a_s___t_e_s_t___c_o_m_p_l_e_x" ],
    [ "CBLAS_TEST_ZOMPLEX", "de/d3b/struct_c_b_l_a_s___t_e_s_t___z_o_m_p_l_e_x.html", "de/d3b/struct_c_b_l_a_s___t_e_s_t___z_o_m_p_l_e_x" ]
];